# samaraenergo

Python клиент электросбытовой компании [СамараЭнерго](https://www.samaraenergo.ru/).

Писался как отдельная [PyPI](https://pypi.org/project/samaraenergo/) библиотека для интеграции с [Home Assistant](https://www.home-assistant.io/).
